<?php
/**
 * @copyright Copyright (c) 2016 https://FiloBludraji.wordpress.com
 */

namespace FiloBlu\ExtViSualMerchandiser\Ui\Component\Listing\Column;

use Magento\Catalog\Model\Category as MagentoCategory;
use Magento\Catalog\Model\ProductFactory;
use Magento\Framework\App\ObjectManager;
use Magento\Framework\View\Element\UiComponent\ContextInterface;
use Magento\Framework\View\Element\UiComponentFactory;
use Magento\Ui\Component\Listing\Columns\Column;

/**
 * Class Price
 */
class Category extends Column
{
    /**
     * @var ProductFactory
     */
    protected $productLoader;
    /**
     * @var MagentoCategory
     */
    protected $categoryLoader;

    /**
     * Category constructor.
     * @param ContextInterface $context
     * @param UiComponentFactory $uiComponentFactory
     * @param ProductFactory $productLoader
     * @param MagentoCategory $categoryLoader
     * @param array $components
     * @param array $data
     */
    public function __construct(
        ContextInterface $context,
        UiComponentFactory $uiComponentFactory,
        ProductFactory $productLoader,
        MagentoCategory $categoryLoader,
        array $components = [],
        array $data = []
    ) {
        parent::__construct($context, $uiComponentFactory, $components, $data);
        $this->productLoader = $productLoader;
        $this->categoryLoader = $categoryLoader;
    }

    /**
     * Prepare Data Source
     *
     * @param array $dataSource
     * @return array
     */
    public function prepareDataSource(array $dataSource)
    {
        $fieldName = $this->getData('name');
        if (isset($dataSource['data']['items'])) {
            foreach ($dataSource['data']['items'] as & $item) {
                $p_id = $item['entity_id'];
                $product = $this->productLoader->create()->load($p_id);
                $cats = $product->getCategoryIds();
                $objectManager = ObjectManager::getInstance();
                $categories = [];
                if (count($cats)) {
                    foreach ($cats as $cat) {
                        $category = $objectManager->create(MagentoCategory::class)->load($cat);
                        $categories[] = $category->getName();
                    }
                }
                $item[$fieldName] = implode(',', $categories);
            }
        }
        return $dataSource;
    }
}
